local name = ...
local mod = LibStub("AceAddon-3.0"):NewAddon(name, "AceEvent-3.0", "AceTimer-3.0")
local timer

local ldbdata = {
	type = "data source",
	text = "|cff00ff000:00:00|r",
	label = "CombatTime",
}

LibStub("LibDataBroker-1.1"):NewDataObject("Broker_CombatTime", ldbdata)

local combatStart = 0
local combatEnd = 0

function mod:OnEnable()
	self:RegisterEvent("PLAYER_REGEN_DISABLED")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("PLAYER_ENTERING_WORLD", "PLAYER_REGEN_ENABLED")
end

function mod:OnDisable()
	self:UnRegisterEvent("PLAYER_REGEN_DISABLED")
	self:UnRegisterEvent("PLAYER_REGEN_ENABLED")
	self:UnRegisterEvent("PLAYER_ENTERING_WORLD")
end

-- Leaving combat
function mod:PLAYER_REGEN_ENABLED()
	if combatStart <= 0 then return end -- We've never been in combat

	combatEnd = GetTime()
	self:Update()
	self:CancelTimer(timer, true)
end

-- Entering combat
function mod:PLAYER_REGEN_DISABLED()
	combatStart = GetTime()
	combatEnd = 0
	self:Update()
	timer = self:ScheduleRepeatingTimer(self.Update, 0.1)

end

local function getCurrentCombatTime()
	local sec = 0

	if InCombatLockdown() then
		sec = GetTime() - combatStart
	else
		sec = combatEnd - combatStart
	end

	if(sec < 0) then
		sec = 0
	end

	local s = math.floor(sec)
	local frac = (sec - s)*100
	local m = math.floor(sec/60)
	sec = math.fmod(sec, 60)

	return ("%d:%02d:%02d"):format(m, sec, frac)
end

function mod:Update()
	if InCombatLockdown() then
		ldbdata.text = "|cffff0000".. getCurrentCombatTime() .."|r"
	else
		ldbdata.text = "|cff00ff00".. getCurrentCombatTime() .."|r"
	end
end
